Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InternalServerError ¶
func InternalServerError(rw http.ResponseWriter, r *http.Request)
InternalServerError is an http handler that returns a JSON response when an error that can not be managed by the handler is encountered during requests handling
func JSON ¶
func JSON(w http.ResponseWriter, body interface{})
JSON is a convenient function to write a JSON object as response to the incoming request
func MethodNotAllowed ¶
func MethodNotAllowed(rw http.ResponseWriter, r *http.Request)
MethodNotAllowed is an http handler that return a JSON response when the method of current request has not been defined for current route
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.